Learn R Programming

etasFLP (version 2.2.2)

b.guten: Estimates the parameter of the Gutenberg-Richter law.

Description

Estimates the parameter of the Gutenberg-Richter law for the magnitude distribution of earthquakes, given a threshold magnitude; it uses moment estimator on transformed data.

Usage

b.guten(magn, m0=min(magn))

Value

b

estimate of the parameter \(b\) of the Gutenberg-Richter Law.

se

estimate of the standard error of the estimate b.

Arguments

magn

a vector of magnitudes coming from an earthquake catalog.

m0

A threshold value. Only values of magn not less than m0 will be used.

Author

Marcello Chiodi

Details

Maximum likelihodd estimation for the Gutenberg-Richter Law:

$$\log_{10} N(>m) = a - b \ M $$

where \(N(>m)\) is the number of events exceeding a magnitude \(m\) and \(a,b\) are two parameters: \(a\) is related to the total seismicity rate of the region while \(b\), to be estimated, should be usually near 1.

Catalog is assumed to be complete (in a certain space-time region) at least for a magnitude m0, that is, every earthquake of magnitude at least m0 in that space-time region, is certainly present in the catalog.

References

Gutenberg, B. and Richter, C. F. (1944). Frequency of earthquakes in California. Bulletin of the Seismological Society of America, 34, 185-188.

See Also

magn.plot

Examples

Run this code

data(italycatalog)
b.guten(italycatalog$magn1)

Run the code above in your browser using DataLab