Learn R Programming

etasFLP (version 2.2.2)

catalog.withcov: Small sample catalog of italian earthquakes with covariates

Description

A small sample catalog of italian earthquakes of magnitude at least 2.5 from May 2012 to May 2016 with extra information.

Usage

catalog.withcov

Arguments

Format

a data matrix with 2,226 observations and 11 variables: Date, id_ev, time, lat, long, z, magn1, err_h_rev, min_distance_rev, rms_rev, nstaloc_rev .

Details

A small sample catalog of italian earthquakes of magnitude at least 2.5 from May 2012 to May 2016 with extra information. Date is the date, id_ev is an identifier of the events, time, lat, long, z, magn1 are time (days from 1900-01-01), latitude, longitude, depth, magnitude, err_h_rev is an estimate of hypocentral uncertainty, min_distance_rev is the distance from the nearest station, rms_rev is a measure of the quality of the location, nstaloc_rev is the number of stations that registered the event, distmin is the distance from the nearest fault

References

INGV home page: https://www.ingv.it/.

Examples

Run this code
data(catalog.withcov)
str(catalog.withcov)

Run the code above in your browser using DataLab