View source: R/compare.etasclass.R
| compare.etasclass | R Documentation |
Compare the results of two etasclass executions through the comparison of some elements of two etasclass objects.
compare.etasclass(etas1,etas2)
etas1 |
an |
etas2 |
an |
Compare the results of two etasclass executions through the comparison of some elements of two etasclass objects estimated on the same catalog. If some standard erros are missing (or zero for constant parameters) they are not used in the standardized comparison of parameters (output object diffstd.params).
diffstd.params |
Standardized comparison of the estimated parameters, included covariates. |
AIC |
Difference of AIC values. |
weigths |
Comparison of the weights |
rho.weigths |
Standardized comparison of the weights |
cor.weights |
Correlation between the weights |
cor.trig |
Correlation between the triggered intensities of the two input objects |
cor.back |
Correlation between the background intensities of the two input objects |
Marcello Chiodi
etasclass
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.