A daily estimation on a space grid is made
daily.etasclass(x, ngrid = 201, nclass = 20, tfixed = 0, flag.log = FALSE, ...)a grid with daily theoretical intensities
an etasclass object
subdivisions of x and y axis for grid computation of intensities
number of class for horizontal and vertical axes of the output grid
day of computation
if log intensity must be used
other optional parameters