Learn R Programming

etasFLP (version 1.3.0)

etas.starting: Guess starting values of ETAS parameters (beta-version). Only from package version 1.2.0

Description

etas.starting is a simple function to give starting values of the 8 ETAS parameters for the function etasclass.

It gives only rough approximation, based on some assumptions, intended to give only the order of magnitude of each parameter (but should be better than nothing). Returns a list with 8 starting values. With this beta-version user must give manually the output of this function in the input of etasclass

Usage

etas.starting(cat.orig, m0=2.5, p.start=1, a.start=1.5, gamma.start=0.5, q.start=2, longlat.to.km=TRUE, sectoday=TRUE )

Arguments

cat.orig
An earthquake catalog, possibly an object of class eqcat, or however a data.frame with variables of names time, lat, long, z, magn1. No missing values are allowed.
m0
Threshold magnitude (only events with a magnitude at least magn.threshold will be used). Default value = 2.5.
p.start
Parameter 4 of the ETAS model; the exponent of the Omori law for temporal decay rate of aftershocks; see details. Default value = 1.0.

a.start
Parameter 5 ($\alpha$) of the ETAS model; efficiency of an event of given magnitude in generating aftershocks; see details. Default value = 1.5.

gamma.start
Parameter 6 ($\gamma$) of the ETAS model; together with a is related to the efficiency of an event of given magnitude in generating aftershocks; see details. Default value = 0.5.

q.start
Parameter 8 of the ETAS model; parameter related to the spatial influence of the mainshock; see details. Default value = 2.

sectoday
if TRUE, then time variable of cat.orig is converted from seconds to days. Default value = TRUE.
longlat.to.km
if TRUE, then long and lat variables of cat.orig are treated as geographical coordinates and converted to kilometers. Default value = TRUE.

Value

returns a list:
mu.start
guess value for mu
k0.start
guess value for k0
c.start
guess value for c
p.start
guess value for p (the same as input value)
a.start
guess value for a (the same as input value)
gamma.start
guess value for gamma (the same as input value)
d.start
guess value for d
q.start
guess value for q (the same as input value)
longlat.to.km
longlat.to.km (the same as input value)
sectoday
sectoday (the same as input value)

Details

It is a beta-version of a very crude method to give starting values for the eight parameters of an ETAS (Epidemic type aftershock sequences) model for the description of the seismicity of a space-time region. These starting values can be used as input for the function etasclass sectoday and longlat.to.km flags must the same that will be used in etasclass.

In this first attempt to give starting values for the ETAS model, many approximations are used

It gives only rough approximation, based on some assumptions, intended to give only the order of magnitude of each parameter (but it should be better than nothing). It returns a list with 8 starting values. With this beta-version user must give manually the output of this function in the input of etasclass.

The values of p.start, a.start, gamma.start and q.start must be however given by the user (we did not find anything reasonable). Default choices for p and q (p.start=1, q.start=2) are strongly reccomended.

c and d are estimated from the emprical distributions of time differences and space distances, respectively. mu and k0 are then estimated from the starting valus the other six parameters, solving the two ML equations, that is derivatives of the whole likelihood with respect to mu and k0 equated to zero. In the computation of the likelihood an approximation for the integral of the intensity function is used (quoted also in Schoenberg (2013)).

References

Schoenberg, F. P. (2013).Facilitated Estimation of ETAS. Bulletin of the Seismological Society of America, Vol. 103, No. 1, pp. 601-605, February 2013, doi: 10.1785/0120120146

See Also

etasclass