A simple and quick 2-d weighted normal kernel estimator, with fixed bandwidth and relative integral.
kde2dnew.fortran(
# parallel=FALSE,
xkern,ykern,gx,gy,h,
factor.xy=1,eps=0,w=replicate(length(xkern),1),
hvarx=replicate(length(xkern),1),hvary=replicate(length(xkern),1)
)kde2d.integral(xkern,ykern,gx=xkern,gy=ykern,eps=0,factor.xy=1,
h = c( bwd.nrd(xkern,w),bwd.nrd(ykern,w)),w=replicate(length(xkern),1),
hvarx=replicate(length(xkern),1),hvary=replicate(length(xkern),1)
)
grid values and estimated densities.
x-values of kernel points of length n (n=length(xkern)).
y-values of kernel points of length n.
x-values of the points where densities must be estimated.
y-values of the points where densities must be estimated.
bandwidths: a length 2 numerical vector.
enlargment factor for the region of interest.
expansion factor for bandwidths (density will be smoother if factor.xy>1).
vector of weights to give to observed points (length n).
[]
Longitude bandwidths adjustement used in the kernel estimator of background seismicity. The length must be equal to the number of events of the catalog after event selection (can be less than nrow(cat.orig)). Default value = replicate(length(xkern),1)
Longitude bandwidths adjustement used in the kernel estimator of background seismicity. The length must be equal to the number of events of the catalog after event selection (can be less than nrow(cat.orig)).Default value = replicate(length(xkern),1)
Marcello Chiodi.
A standard bivariate normal kernel estimator.
Venables, W. N. and Ripley, B. D. (2002) Modern Applied Statistics with S. Fourth edition. Springer. Wand, M.P and Jones, M.C. (1995). Kernel Smoothing. London: Chapman & Hall/CRC.