etasclass.Gives some information on the execution and gives estimates of the ETAS parameters.
"print"(x,...)etaclass object.etasclass
estimation process. Displays also the exact call of the function that generated etasclass
etasclass. More output is obtained with summary.
etasclass,eqcat, profile.etasclass