Learn R Programming

etasFLP (version 1.0.2)

profile.etasclass: profile method for etasclass objects (ETAS model)

Description

profile method for etasclass objects (ETAS model).

Usage

## S3 method for class 'etasclass':
profile(fitted,iprofile		=4,
				 nprofile	=7,
				 kprofile	=3,
				 profile.approx	=FALSE,...)

Arguments

fitted
An object of the class etasclass
iprofile
An integer in the range 1-8. Profile likelihood will be computed with respect to the parameter of index iprofile. The order of parametrs is: mu, k0, c, p, a, gamma,
nprofile
Number of values of params[iprofile] for which profile likelihood must be computed. Default value= 7.
kprofile
Maximum absolute standardized value for params[iprofile]. Profile likelihood will be computed in the standardized range [-kprofile, kprofile]. Default value= 3.
profile.approx
if TRUE, then a conditional-likelihood approach is used as a first value for each maximization step in profile likelihood computation. Default value= FALSE.
...
other arguments.

Value

  • Returns a list:
  • params.vecvector of values of the parameter iprofile used to evaluate the profile likelihood.
  • logl.vecvector of likelihoods corresponding to the values of params.vec
  • plot method is defined to represent profile likelihood (in scale -2log(LR)), using a spline interpolation through grid points, with superimposition of approximate confidence intervals.

Details

Profile likelihood for the iprofile-th parameter of the ETAS model for earthquake seismicity, estimated with etasclass; the order of parameters is: (mu,k0,c,p,a,gamma,d,q). A plot method is defined for profile.etasclass objects. A number of grid points nprofile of 7 (the default) usually is enough to have a good interpolation of the profile likelihood. The profile is computed using the final estimation of the background seismicity used to obtain the object etas of class etasclass and regardless to the method used. The computing time (for each of the nprofile values) is generally less than a single execution of etasclass without clustering, because only ML estimation is performed. Parameters not estimated in etas (with params.ind[i]=FALSE) will remain fixed do the value params.fix[i]. To obtain profiles for different parameters, run profile.etasclass with different values of iprofile.

See Also

eqcat, etasclass, plot.profile.etasclass

Examples

Run this code
##
data("italycatalog")
# load a sample catalog of italian seismicity  

etasclass(cat.orig = italycatalog, magn.threshold = 3.1, magn.threshold.back = 3.5, 
    k0 = 0.005, c = 0.005, p = 1.01, a = 1.05, gamma = 0.6, d = 1.1, 
    q = 1.52, params.ind = c(TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, 
        TRUE, TRUE), declustering = TRUE, thinning = FALSE, flp = TRUE, 
    ndeclust = 15, onlytime = FALSE, is.backconstant = FALSE, 
    description = "etas flp", sectodacatalog-search.htmly = TRUE, usenlm = TRUE, 
    epsmax = 0.001)


# profile likelihood for the 5-th parameter (a), with plot:

prof.flp=profile(etas.flp,nprofile=7,iprofile=5)
plot(prof.flp)
> plot(prof.flp)
Asymptotic  confidence  intervals: 
  Coverage Lower Upper
1     0.90 1.514 1.766
2     0.95 1.501 1.778
3     0.99 1.463 1.805

Run the code above in your browser using DataLab