Maximum likelihodd estimation for the Gutenberg-Richter Law:
$$\log_{10} N(>m) = a - b \ M $$
where \(N(>m)\) is the number of events exceeding a magnitude \(m\) and \(a,b\) are two parameters: \(a\) is related to the total seismicity rate of the region while \(b\), to be estimated, should be usually near 1.
Catalog is assumed to be complete (in a certain space-time region) at least for a magnitude m0,
that is, every earthquake of magnitude at least m0 in that space-time region, is certainly present in the catalog.