Computes the optimal bandwidth with the Silverman rule, for a kernel
estimator with points x and weights w.
If a multivariate kernel is used, (i.e. d > 1),
bwd.nrd must be called for each variable. It computes dispersion only with the weighted standard deviation, with no robust alternative. Called by kde2dnew.fortran.