compare.etasclass: Compare two etasclass objects
Description
Compare the results of two etasclass executions through the comparison of some elements of two etasclass objects.Usage
compare.etasclass(etas1,etas2)
Arguments
etas1
an etasclass object.
etas2
an etasclass object.
Value
- paramsStandardized comparison of the estimated parameters.
- AICDifference of AIC values.
- weigthsComparison of the weights
rho.weights of the two input objects. - rho.weigthsStandardized comparison of the weights
rho.weights of the two input objects. - cor.weightsCorrelation between the weights
rho.weights of the two input objects - cor.trigCorrelation between the triggered intensities of the two input objects
- cor.backCorrelation between the background intensities of the two input objects
Details
Compare the results of two etasclass executions through the comparison of some elements of two etasclass objects. Fundamental elements (catalog, threshold magnitude) should be equal, but no check is made