etas.starting is a simple function to give starting values of the 8 ETAS parameters for the function etasclass.It gives only rough approximation, based on some assumptions, intended to give only the order of magnitude of each parameter (but should be better than nothing).
Returns a list with 8 starting values. With this beta-version user must give manually the output of this function in the input of etasclass
etas.starting(cat.orig,
m0=2.5,
p.start=1,
a.start=1.5,
gamma.start=0.5,
q.start=2,
longlat.to.km=TRUE,
sectoday=TRUE
)eqcat, or however a data.frame with variables of names time, lat, long, z, magn1. No missing values are magn.threshold will be used). Default value = 2.5.a is related to the efficiency of an event of given magnitude
in generating aftershocks; see details. Default value = 0.5.TRUE, then time variable of cat.orig is converted from seconds to days. Default value = TRUE.TRUE, then long and lat variables of cat.orig are treated as geographical coordinates and converted to kilometers. Default value = TRUE.muk0cp (the same as input value)a (the same as input value)gamma (the same as input value)dq (the same as input value)longlat.to.km (the same as input value)sectoday (the same as input value)etasclass
sectoday and longlat.to.km flags must the same that will be used in etasclass.In this first attempt to give starting values for the ETAS model, many approximations are used
It gives only rough approximation, based on some assumptions, intended to give only the order of magnitude of each parameter (but it should be better than nothing). It
returns a list with 8 starting values. With this beta-version user must give manually the output of this function in the input of etasclass.
The values of p.start, a.start, gamma.start and q.start must be however given by the user (we did not find anything reasonable). Default choices for p and q (p.start=1, q.start=2) are strongly reccomended.
c and d are estimated from the emprical distributions of time differences and space distances, respectively.
mu and k0 are then estimated from the starting valus the other six parameters, solving the two ML equations, that is derivatives of the whole likelihood with respect to mu and k0 equated to zero.
In the computation of the likelihood an approximation for the integral of the intensity function is used (quoted also in
Schoenberg (2013)).
etasclass