Learn R Programming

etasFLP (version 1.0.2)

etasFLP-package: Estimation of an ETAS model for earthquake description. ML (maximum Likelihood) and FLP (Forward Likelihood Predictive) estimation of parametric and non-parametric components.

Description

Estimation of the components of an ETAS (Epidemic Type Aftershock Sequences) model for the description of the seismicity of a space-time region. Background seismicity is estimated non-parametrically, while triggered seismicity is estimated by MLE. The bandwidth for a kernel smoothing can be estimated through the Forward Likelihood Predictive approach (FLP); probability of being an aftershock can be estimated for each event, too. Also plot, print, summary, profile methods are defined for the output of the main function etasclass.

Arguments

Details

ll{ Package: etasFLP Type: Package Version: 1.0.2 Date: 2014-3-27 License: GPL (>=2) Depends: R (>= 2.14.0), fields, rgl, maps, mapdata, car Suggests: MASS } etasclass is the main function of the package etasFLP.

References

Adelfio, G. and Chiodi, M. (2013) Mixed estimation technique in semi-parametric space-time point processes for earthquake description. Proceedings of the 28th International Workshop on Statistical Modelling 8-13 July, 2013, Palermo (Muggeo VMR, Capursi V, Boscaino G, Lovison G, editors). Vol. 1. pp.65-70.

Chiodi, M. and Adelfio, G., (2011) Forward Likelihood-based predictive approach for space-time processes. Environmetrics, vol. 22 (6), pp. 749-757.

Console, R., Jackson, D. D. and Kagan, Y. Y. Using the ETAS model for Catalog Declustering and Seismic Background Assessment. Pure Applied Geophysics 167, 819--830 (2010).

Ogata, Y. Statistical models for earthquake occurrences and residual analysis for point processes. Journal of the American Statistical Association, 83, 9--27 (1988).

Veen, A. and Schoenberg, F.P. Estimation of space-time branching process models in seismology using an EM-type algorithm. Journal of the American Statistical Association, 103(482), 614--624 (2008).

Zhuang, J., Ogata, Y. and Vere-Jones, D. Stochastic declustering of space-time earthquake occurrences. Journal of the American Statistical Association, 97, 369--379 (2002).