Learn R Programming

etasFLP (version 1.2.0)

kde2dnew.fortran: A 2-d normal kernel estimator

Description

A simple and quick 2-d weighted normal kernel estimator, with fixed bandwidth and relative integral.

Usage

kde2dnew.fortran(xkern, ykern, gx, gy, h, factor.xy = 1,eps=0, w =
 replicate(length(xkern), 1))

kde2d.integral(xkern, ykern, gx = xkern, gy = ykern, eps = 0, factor.xy = 1, h = c(bwd.nrd(xkern, w), bwd.nrd(ykern, w)), w = replicate(length(xkern), 1),wmat=numeric(0))

Arguments

xkern
x-values of kernel points of length n (n=length(xkern)).
ykern
y-values of kernel points of length n.
gx
x-values of the points where densities must be estimated.
gy
y-values of the points where densities must be estimated.
h
bandwidths: a length 2 numerical vector.
factor.xy
expansion factor for bandwidths (density will be smoother if factor.xy>1).
w
vector of weights to give to observed points (length n).
wmat
if kern.var=TRUE defines the variable metric
eps
enlargment factor for the region of interest.

Value

  • grid values and estimated densities.

Details

A standard bivariate normal kernel estimator.

References

Venables, W. N. and Ripley, B. D. (2002) Modern Applied Statistics with S. Fourth edition. Springer. Wand, M.P and Jones, M.C. (1995). Kernel Smoothing. London: Chapman & Hall/CRC.