Learn R Programming

etasFLP (version 1.0.2)

print.etasclass: Print method for etasclass objects

Description

Print method for an object of class etasclass.

Gives some information on the execution and gives estimates of the ETAS parameters.

Usage

## S3 method for class 'etasclass':
print(x,...)

Arguments

x
an etaclass object.
...
other arguments.

Value

  • Displays parameters estimates and information on the execution of the etasclass estimation process. Displays also the exact call of the function that generated etasclass

Details

Print brief information about an object of class etasclass. More output is obtained with summary.

See Also

etasclass,eqcat, profile.etasclass